%-------------------------------------------------------------------------%
%        THE WITHIN-COUNTRY DISTRIBUTION OF BRAIN DRAIN AND BRAIN         %
%                   GAIN EFFECTS: A CASE STUDY ON SENEGAL                 %
%                   Journal of Demograhic Economics (2024)                %
%                               Authors :                                 %
%           Bocquier P., Cha'ngom N., Docquier F., and Machado J.         %
%-------------------------------------------------------------------------%

% Counterfactual exercises here postulate exogenous wages 
%-------------------------------------------------------------------------%
%            SCENARIO 3 - CLOSED OECD BORDERS (NO OECD MIG)               %
%-------------------------------------------------------------------------%

wHiNM = wHi;wLiNM = wLi; wHjNM = wHj; wLjNM = wLj;
cijhNM = cijhNoecdMa +(1-cijhNoecdMa).*cijh; cijlNM = cijlNoecdMa +(1-cijlNoecdMa).*cijl; % No OECD migration (NoecdM)
WijhNM = (1-dumst).*(wHjNM.*(1-cijhNM)).^(1/mu);
WijlNM = (1-dumst).*(wLjNM.*(1-cijlNM)).^(1/mu);
WikhNM = (1-dumst).*((wHjNM./wHiNM).*(1-cijhNM)).^mu;
WiklNM = (1-dumst).*((wLjNM./wLiNM).*(1-cijlNM)).^mu;
AttractNM = table(i,WijhNM,WijlNM,WikhNM,WiklNM);
SumAttractNM = varfun(@sum,AttractNM,"InputVariables",{'WijhNM','WijlNM','WikhNM','WiklNM'},"GroupingVariables",{'i'}); % sum across all destinations (j)
SumWijhNM = SumAttractNM.sum_WijhNM; SumWijlNM =SumAttractNM.sum_WijlNM;
SumWikhNM = 1+SumAttractNM.sum_WikhNM; SumWiklNM = 1+SumAttractNM.sum_WiklNM;

i = SumAttractNM.i;
locNM = table(i,SumWijhNM,SumWikhNM,SumWijlNM,SumWiklNM);
longNM = outerjoin(locNM,Ui,'Type','left','Keys',{'i'},'MergeKeys',true);
longNM = sortrows(longNM,{'i','j'});
longNM.SumWijhNM = (1-dumst).*longNM.SumWijhNM;
longNM.SumWijlNM = (1-dumst).*longNM.SumWijlNM;
wH_expNM = wHiNM.^(1/mu) + longNM.SumWijhNM;
wL_expNM = wLiNM.^(1/mu) + longNM.SumWijlNM;
LambdaNM = wH_expNM./wL_expNM; 

mHNM = (longNM.SumWijhNM)./wH_expNM; 
mLNM = (longNM.SumWijlNM)./wL_expNM; 
RatioNM = 1 - 1./LambdaNM; 
HniNM = (Gstar.*RatioNM).^(1+zstar); 
i = longNM.i;
NihNM = Ni.*HniNM; NilNM = Ni.*(1-HniNM);

%-------------------------------------------------------------------------%
%                      Endogenous NM structure                            %
%-------------------------------------------------------------------------%
NiihNM = NihNM.*(1-mHNM);
NiilNM = NilNM.*(1-mLNM);
MijHNM = (1-dumst).*(((wHjNM./wHiNM).*(1-cijhNM)).^(1/mu)).*NiihNM; 
MijLNM = (1-dumst).*(((wLjNM./wLiNM).*(1-cijlNM)).^(1/mu)).*NiilNM; 

migdtaNM = table(i,j,MijHNM,MijLNM);
EmigNM = varfun(@sum,migdtaNM,"InputVariables",{'MijHNM','MijLNM'},"GroupingVariables",{'i'}); % sum across all destinations (j)
EmigNM = renamevars(EmigNM,["sum_MijHNM","sum_MijLNM"],["EmHNM","EmLNM"]);
EmigNM.GroupCount=[] ; 
EmigNM.i=[] ; 
migdtaNM = migdtaNM(migdtaNM.j < 144,:);
ImigNM = varfun(@sum,migdtaNM,"InputVariables",{'MijHNM','MijLNM'},"GroupingVariables",{'j'}); % sum across all origins (i)
ImigNM = renamevars(ImigNM,["j","sum_MijHNM","sum_MijLNM"],["i","ImHNM","ImLNM"]);
ImigNM.GroupCount=[] ; 
SumendoNM =[EmigNM,ImigNM];

longMigNM = outerjoin(SumendoNM,Ui,'Type','left','Keys',{'i'},'MergeKeys',true);
LihNM = NiihNM+longMigNM.ImHNM; LilNM = NiilNM+longMigNM.ImLNM; 
HriNM = LihNM./(LihNM+LilNM);

scatter(Hri,HriNM)
hold on
scatter(Hni,HniNM)
WelfareHNM = (1-dumst).*wH_expNM; 
WelfareLNM = (1-dumst).*wL_expNM;

%-------------------------------------------------------------------------%
%                        Results export Autarky                           %
%-------------------------------------------------------------------------%
ImHNM = longMigNM.ImHNM; ImLNM = longMigNM.ImLNM; EmHNM = longMigNM.EmHNM; EmLNM = longMigNM.EmLNM;
ResNoecdM = table(i,o_iso,ImHNM,ImLNM,EmHNM,EmLNM,LambdaNM,HriNM,HniNM,WelfareHNM,WelfareLNM,dumst);
ResNoecdM = ResNoecdM(ResNoecdM.dumst==0,:);

ResNoecdM = varfun(@mean,ResNoecdM,"InputVariables",{'ImHNM','ImLNM','EmHNM','EmLNM','LambdaNM','HriNM','HniNM','WelfareHNM','WelfareLNM'},"GroupingVariables",{'i','o_iso'});

ResNoecdM = renamevars(ResNoecdM,["mean_ImHNM","mean_ImLNM","mean_EmHNM","mean_EmLNM","mean_LambdaNM","mean_HriNM","mean_HniNM","mean_WelfareHNM","mean_WelfareLNM"] ...
                                ,["ImHNoecdM","ImLNoecdM","EmHNoecdM","EmLNoecdM","LambdaNoecdM","HriNoecdM","HniNoecdM","WelfareHNoecdM","WelfareLNoecdM"]);


 warning('off','MATLAB:xlswrite:AddSheet');
 writetable(ResNoecdM,'U:\CHANGOM\JODE\Matlab_code\Replication_file_BCDM2024\STATA\Data\JODE_calib_output.xlsx','Sheet',4);
 e = actxserver('Excel.Application');  
 ewb = e.Workbooks.Open('U:\CHANGOM\JODE\Matlab_code\Replication_file_BCDM2024\STATA\Data\JODE_calib_output.xlsx');  
 ewb.Worksheets.Item(4).Name = 'OecdAutarky';  
 ewb.Save
 ewb.Close(false)
 e.Quit
 

