

*-------------------------------------------------------------------------%
*                             01 - Load  Matlab output                    %
*-------------------------------------------------------------------------%

* Initial values 
import excel "$data\JODE_calib_output.xlsx", sheet("Initial") firstrow clear
save "$cleaned\InitEquil", replace 

* Autarky simulation 
import excel "$data\JODE_calib_output.xlsx", sheet("Autarky") firstrow clear
drop GroupCount 
save "$cleaned\Autarky", replace 


* Domestic autarky simulation 
import excel "$data\JODE_calib_output.xlsx", sheet("DomAutarky") firstrow clear
drop GroupCount 
save "$cleaned\DomAutarky", replace 

* OECD autarky simulation 
import excel "$data\JODE_calib_output.xlsx", sheet("OecdAutarky") firstrow clear
drop GroupCount 
save "$cleaned\OecdAutarky", replace 


*-------------------------------------------------------------------------%
*                       02 - Combine Simulated scenarios                  %
*-------------------------------------------------------------------------%
use "$cleaned\InitEquil", clear 
merge 1:1 i using "$cleaned\Autarky" 
drop _m 
merge 1:1 i using "$cleaned\DomAutarky"
drop _m 
merge 1:1 i using "$cleaned\OecdAutarky"
drop _m 
merge n:1 o_iso using "$data\dep_reg" 
drop GroupCount _m depart_name depart_code sep 
sort i 
save "$cleaned\Combined_JODE", replace 


*-------------------------------------------------------------------------%
*                             03 - Graphical analysis                     %
*-------------------------------------------------------------------------%
* Absolute deviation in HC 
gen dh_a = Hri-HriNM      // a - Autarky 
gen dh_b = Hri-HriNIM     // b - Domestic Autarky 
gen dh_c = Hri-HriNoecdM  // c - OECD Autarky 

* Relative deviation in expected Welfare  	
gen d_welh_a = log(WelfareH)-log(WelfareHNM) // a - Autarky 
gen welh_NMa = log(WelfareHNM)
gen d_well_a = log(WelfareL)-log(WelfareLNM)
gen well_NMa = log(WelfareLNM)

gen d_welh_b = log(WelfareH)-log(WelfareHNIM) // b - Domestic Autarky
gen welh_NMb = log(WelfareHNIM)
gen d_well_b = log(WelfareL)-log(WelfareLNIM)
gen well_NMb = log(WelfareLNIM)

gen d_welh_c = log(WelfareH)-log(WelfareHNoecdM) // c - OECD Autarky 
gen welh_NMc = log(WelfareHNoecdM)
gen d_well_c = log(WelfareL)-log(WelfareLNoecdM)
gen well_NMc = log(WelfareLNoecdM)

* Relative deviation in education premium 
gen Xa = LambdaNM
gen Ya = Lambda/LambdaNM-1
gen Xb = LambdaNIM
gen Yb = Lambda/LambdaNIM-1	
gen Xc = LambdaNoecdM
gen Yc = Lambda/LambdaNoecdM-1	
	
lab var Xa "lambdaNM"
lab var Xb "lambdaNM-internal"
lab var Xc "lambdaNM-oecd"	
lab var Ya "Dln-lambdaNM"
lab var Yb "Dln-lambdaNM-internal"
lab var Yc "Dln-lambdaNM-oecd"
	
	local Y Ya Yb Yc 
	foreach v in `Y' {
	    gen `v'1 = min(2, `v')
	}

